import unittest
import os
import cv_basic_utils as mlu
from cv_basic_utils.path_utils.path_utils import makedir, get_file_name, delete_file, deletedir, get_files

class TestPathUtils(unittest.TestCase):
    def test_makedir(self):
        direc = './test_dir'
        if os.path.exists(direc):
            deletedir(direc)
        self.assertTrue(makedir(direc))
        self.assertTrue(os.path.exists(direc))
        self.assertFalse(makedir(direc))
        deletedir(direc)
        
    def test_get_file_name(self):
        filepath = './test_dir/test_file.txt'
        self.assertEqual(get_file_name(filepath), 'test_file')
        
    def test_delete_file(self):
        filepath = './test_dir/test_file.txt'
        makedir('./test_dir')
        with open(filepath, 'w') as f:
            f.write('test')
        self.assertTrue(delete_file(filepath))
        self.assertFalse(os.path.exists(filepath))
        self.assertFalse(delete_file(filepath))
        os.rmdir('./test_dir')
        
    def test_deletedir(self):
        direc = './test_dir'
        makedir(direc)
        self.assertTrue(deletedir(direc))
        self.assertFalse(os.path.exists(direc))
        self.assertFalse(deletedir(direc))
    
    def test_get_files(self):
        direc = './test_dir'
        makedir(direc)
        files = [os.path.join(direc, f) for f in os.listdir(direc) if os.path.isfile(os.path.join(direc, f))]
        self.assertEqual(len(files), 0)
        for i in range(10):
            with open(os.path.join(direc, 'test_file_{}.txt'.format(i)), 'w') as f:
                f.write('test')
        files = [os.path.join(direc, f) for f in os.listdir(direc) if os.path.isfile(os.path.join(direc, f))]
        self.assertEqual(len(files), 10)
        files = [os.path.join(direc, f) for f in os.listdir(direc) if os.path.isfile(os.path.join(direc, f)) and os.path.splitext(f)[1] == '.txt']
        self.assertEqual(len(files), 10)
        files = mlu.path_utils.path_utils.get_files(direc, extns=['txt'])
        self.assertEqual(len(files), 10)
        files = mlu.path_utils.path_utils.get_files(direc)
        self.assertEqual(len(files), 10)
        files = mlu.path_utils.path_utils.get_files(direc, extns=['png'])
        self.assertNotEqual(len(files), 10)

        deletedir(direc)



if __name__ == '__main__':
    unittest.main()


import cv_basic_utils as mlu
import unittest


class TestModuleB(unittest.TestCase): 
    
    def test_fun_b(self):
        self.assertTrue(mlu.subpackage2.moduleB.fun_b())
    
if __name__ == '__main__':
    unittest.main() 





# https://medium.com/@udiyosovzon/things-you-should-know-when-developing-python-package-5fefc1ea3606
import setuptools
with open('./requirements.txt') as f:
    required = f.read().splitlines()
with open("README.md", "r") as fh:
    long_description = fh.read()
setuptools.setup(
    name="cv_basic_utils",
    version="0.0.4",
    author="Jerin K A",
    author_email="jerin.electronics@gmail.com",
    description="Common utils for machine learning, computer vision",
    url = 'https://github.com/jerinka/cv_basic_utils',
    download_url = 'https://github.com/jerinka/cv_basic_utils/archive/refs/tags/v0.0.3.tar.gz',
    keywords = ['machine-learning', 'utils', 'vision-utils'],
    install_requires=required,
    long_description=long_description,
    long_description_content_type="text/markdown",
    packages=setuptools.find_packages()
)
